// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com
// Apdo. 964-1250 Escaz, San Jos, Costa Rica
// dedicado a Jess y Mara...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 15 febrero 2011
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// El objeto MSCS_Mesa() tiene las siguientes caracteristicas
// Alto         : 581*L
// Ancho        : 686*L
// Largo        : 1329*L
// SeparacionPatas      : 520*L--786*L (grueso 50*L)
//   Se coloca con la parte inferior centrada en el origen
//   orientado segn el eje X, zona superior y+
// El objeto MSCS_Silla() tiene las siguientes caracteristicas
// Alto         : 771*L
// Alto Asiento : 322*L
// Base Asiento : 278*L--278*L mas exceso de unos 12 a 20*L
// El respaldo del asiento es ligeramente curvo.
//   Se coloca con la parte inferior centrada en el origen
//   orientado segn frente en x+, superior en y+
// La macro MSCS_MesaSillas(), coloca una mesa con seis sillas
//   a cada silla se le aplica rotaciones y un translate del tipo
//   322*L en z a las sillas laterales
//   o bien 615*L en x a las sillas extremas
//   mas alguna aleatoriedad
//
// Para su uso simplemente, utilice una macro default.
// #include "MSCS.inc"
// object       { MSCS_MesaSillas() }
// O bien, MSCS_Mesa() o MSCS_Silla()
//
// Se pueden accesar las macros directamente para modificacin de texturas
// #macro MSCS_MacroMesa ( TexturaMadera )
//      TexturaMadera   : textura que recubrir enteramente al objeto
// #macro MSCS_MacroSilla( TexturaMadera, TexturaTela )
//      TexturaMadera   : recubre la madera de la silla
//      TexturaTela     : cubre el respaldo y el asiento de la silla
//
// Las texturas predefinidas, que no deberan modificarse son
// MSCS_TexturaMadera   : textura predefinida de la madera
// MSCS_TexturaTela     : textura predefinida de la tela
// El objeto permite los siguientes modificadorse
// #declare MSCS_POV3_1                         = off;
//      si se activa con "on" realiza modificaciones de compatibilidad
//      para ejectuar con POVRay3.1.  En algunas versiones de POVRay
//      se activar automticamente.
// #declare MSCS_TexturaMaderaDefault           = texture {...}
//      permite modificar la madera default del objeto
// #declare MSCS_TexturaTelaDefault             = texture {...}
//      permite modificar la tela default del objeto
// Ejemplo:  
// #include "MSCS.inc"
// #declare MSCS_TexturaTelaDefault             = texture       {
//       average
//       texture_map    {
//          [ 0.5 MSCS_TexturaTela ]
//          [ 0.5 TexturaCustom... ]
//       }
// }
// object       { MSCS_Silla() }
//

#include "woods.inc"
#include "MSCS_Aux.inc"

#declare MSCS_L                 = 0.001;

#declare MSCS_TexturaMadera     = texture       {
  T_Wood24
  scale         10
  rotate        -110
  translate     20
  normal        {
    bumps
    scale       0.01
    turbulence  0.5
  }
}

#ifndef ( MSCS_TexturaMaderaDefault )
  #declare MSCS_TexturaMaderaDefault    = texture       {
    MSCS_TexturaMadera
  }
#end

#declare MSCS_TexturaTela       = texture       {
  pigment {
      quilted  
      control0 0.5
      control1 0.8
      pigment_map { 
          [ 0.0 color Red    ]
          [ 0.3 color Yellow ]
          [ 1.0 color Orange ]
        }
      turbulence 0.4 
      scale     0.02
      rotate    45
  }
  normal  {
      quilted  
      control0 0.5
      control1 0.8
      turbulence 0.4 
      scale     0.02
      rotate    45
  }
}

#ifndef ( MSCS_TexturaTelaDefault )
  #declare MSCS_TexturaTelaDefault      = texture       {
    MSCS_TexturaTela
  }
#end

#macro MSCS_DecoradoBajo( Largo, Grueso, Alto )
    union               {
      #local FactorCil                  = 0.2;
      #local LargoCil                   = FactorCil*Largo;
      #local RadioCil                   = sqrt( 0.2*0.2+1/36 )*Largo;
      difference        {
        box               {
          < -Largo/2      , 0     , -Grueso/2 >,
          < +Largo/2      , Alto      , +Grueso/2 >
        }
        cylinder        {
          < -Largo/3    ,-LargoCil    , -Grueso   >,
          < -Largo/3    ,-LargoCil    ,  Grueso   >,
          RadioCil
        }
        cylinder        {
          < +Largo/3    ,-LargoCil    , -Grueso   >,
          < +Largo/3    ,-LargoCil    ,  Grueso   >,
          RadioCil
        }
      }
      difference        {
        cylinder        {
          < 0   , +LargoCil    , -Grueso/2        >,
          < 0   , +LargoCil    ,  Grueso/2        >,
          RadioCil
        }
        plane           {
          -y    , 0
        }
      }
      cylinder          {
          < -Largo/2      , 0     , -Grueso/2 >,
          < -Largo/2      , 0     , +Grueso/2 >,
          0.05*Largo
      }
    }
#end

#macro MSCS_MacroMesa ( TexturaMadera )
  #local L                              = MSCS_L;
  #local LargoBaseMesa                  = 643*L;
  #local DiametroBase                   = 686*L;
  #local GruesoBase                     = 20*L;
  #local DecoradoBase                   = 15*L;
  #local AltoBaseMesa                   = 561*L;
  #local GruesoDecoradoBajo             = 12*L;
  #local AltoDecoradoBajo               = 53*L;
  #local GruesoPata                     = 50*L;
  #macro MSCS_DecoradoBajoTotal ( Largo, Cantidad, Grueso, Alto )
    union       {
      #local C          = 0;
      #while ( C < Cantidad )
        object          {
          MSCS_DecoradoBajo( Largo/Cantidad, Grueso, Alto )
          translate     -Largo*x/2+C*Largo/Cantidad*x+Largo/Cantidad/2*x
        }
        #local C        = C+1;
      #end
    }
  #end
  #local Pata           = union {
    #local SoporteBox   = 100*L;
    #local AltoSor      = AltoBaseMesa-SoporteBox;
    #local PosicionPata = < 786, 0, 520 >/2*L;
    box                 {
      < -GruesoPata/2   , AltoSor       , -GruesoPata/2 >,
      < +GruesoPata/2   , AltoBaseMesa  ,  GruesoPata/2 >
    }
    sor                 {
      #local FactorSor  = < 1/0.8*GruesoPata/2, AltoSor >;
      15,
      < 0.80,-0.10 >*FactorSor,
      < 0.40, 0.00 >*FactorSor,
      < 0.80, 0.10 >*FactorSor,
      < 0.40, 0.20 >*FactorSor,
      < 0.50, 0.21 >*FactorSor,
      < 0.60, 0.40 >*FactorSor,
      < 0.70, 0.50 >*FactorSor,
      < 0.75, 0.60 >*FactorSor,
      < 0.80, 0.70 >*FactorSor,
      < 0.75, 0.80 >*FactorSor,
      < 0.60, 0.88 >*FactorSor,
      < 0.75, 0.90 >*FactorSor,
      < 0.60, 0.92 >*FactorSor,
      < 0.80, 1.00 >*FactorSor,
      < 0.60, 1.10 >*FactorSor
    }
  }
  
  union                 {
      union             {
      box               {
        < -LargoBaseMesa/2      , 0             , -DiametroBase/2       >,
        <  LargoBaseMesa/2      , GruesoBase    ,  DiametroBase/2       >
      }
      cylinder          {
        -LargoBaseMesa/2*x  , -LargoBaseMesa/2*x+GruesoBase*y   ,
        DiametroBase/2
      }
      cylinder          {
        +LargoBaseMesa/2*x  , +LargoBaseMesa/2*x+GruesoBase*y   ,
        DiametroBase/2
      }
      difference        {
        union           {
          cylinder        {
            -LargoBaseMesa/2*x-DiametroBase/2*z   ,
            +LargoBaseMesa/2*x-DiametroBase/2*z   ,
            DecoradoBase
          }
          cylinder        {
            -LargoBaseMesa/2*x+DiametroBase/2*z   ,
            +LargoBaseMesa/2*x+DiametroBase/2*z   ,
            DecoradoBase
          }
          torus         {
            DiametroBase/2      , DecoradoBase
            translate   -LargoBaseMesa/2*x
          }
          torus         {
            DiametroBase/2      , DecoradoBase
            translate   +LargoBaseMesa/2*x
          }
        }
        plane           {
          y             , 0
        }
      }
      translate         AltoBaseMesa*y
    }
    object      {
      Pata
      translate         PosicionPata
    }
    object      {
      Pata
      translate         PosicionPata*<-1,0,+1>
    }
    object      {
      Pata
      translate         PosicionPata*<-1,0,-1>
    }
    object      {
      Pata
      translate         PosicionPata*<+1,0,-1>
    }
    object      {
      MSCS_DecoradoBajoTotal
        ( 2*PosicionPata.x-GruesoPata, 5,
                GruesoDecoradoBajo, AltoDecoradoBajo  )
      translate ( AltoBaseMesa-AltoDecoradoBajo )*y-PosicionPata.z*z
    }
    object      {
      MSCS_DecoradoBajoTotal( 2*PosicionPata.x-GruesoPata, 5,
                GruesoDecoradoBajo, AltoDecoradoBajo  )
      translate ( AltoBaseMesa-AltoDecoradoBajo )*y+PosicionPata.z*z
    }
    object      {
      MSCS_DecoradoBajoTotal( 2*PosicionPata.z-GruesoPata, 3,
                GruesoDecoradoBajo, AltoDecoradoBajo  )
      rotate    90*y
      translate ( AltoBaseMesa-AltoDecoradoBajo )*y+PosicionPata.x*x
    }
    object      {
      MSCS_DecoradoBajoTotal( 2*PosicionPata.z-GruesoPata, 3,
                GruesoDecoradoBajo, AltoDecoradoBajo  )
      rotate    90*y
      translate ( AltoBaseMesa-AltoDecoradoBajo )*y-PosicionPata.x*x
    }
    texture     {
      TexturaMadera
    }
  }
#end

#macro MSCS_MacroSilla( TexturaMadera, TexturaTela )
  #local L              = MSCS_L;
  #local AltoBase       = 286*L;
  #local GruesoSoporte  = 15*L;
  #local AltoSoporte    = 50*L;
  #local LargoSoporte   = 278*L;
  #local AnchoSoporte   = LargoSoporte;
  #local GruesoPataTrasera      = 24*L;
  #local AltoPataTrasera        = 450*L+AltoBase;
  #local GruesoPataDelantera    = 35*L;
  #local GruesoAsiento          = 36*L;
  #local PataDelantera          = union         {
    #local LisoDelantero        = 70*L;
    box         {
      < -GruesoPataDelantera/2, 0, -GruesoPataDelantera/2 >,
      < +GruesoPataDelantera/2, LisoDelantero, +GruesoPataDelantera/2 >
      translate ( AltoBase-LisoDelantero )*y
    }
    sor         {
      #local LargoSor   = AltoBase-LisoDelantero;
      #local FactorSor  = < GruesoPataDelantera/2, LargoSor >;
      10,
      <+0.40,-0.10 >*FactorSor,
      <+0.40,+0.00 >*FactorSor,
      <+0.50,+0.10 >*FactorSor,
      <+0.90,+0.15 >*FactorSor,
      <+0.60,+0.20 >*FactorSor,
      <+1.00,+0.70 >*FactorSor,
      <+0.60,+0.75 >*FactorSor,
      <+1.00,+0.80 >*FactorSor,
      <+0.70,+1.00 >*FactorSor,
      <+0.70,+1.10 >*FactorSor
    }
  }
  #local AdornoFinPataTrasera   = sor   {
    #local AltoFin              = 35*L;
    #local FactorSor            = < GruesoPataTrasera/2, AltoFin >;
    7,
    <+0.00,-0.10 >*FactorSor,
    <+0.60,+0.00 >*FactorSor,
    <+1.00,+0.10 >*FactorSor,
    <+0.50,+0.60 >*FactorSor,
    <+1.00,+0.80 >*FactorSor,
    <+0.60,+1.00 >*FactorSor,
    <+0.00,+1.10 >*FactorSor
  }
  union         {
    #local C            = 0;
    #while ( C < 4 )
      box         {
        < -LargoSoporte/2 , 0     , -GruesoSoporte/2       >,
        < +LargoSoporte/2 , AltoSoporte   , +GruesoSoporte/2       >
        translate       -LargoSoporte/2*z+( AltoBase-AltoSoporte )*y
        rotate          C*90*y
      }
      #local C          = C+1;
    #end
    #local InicioPataTrasera    =
                < -1.1*LargoSoporte/2, 0, -LargoSoporte/2 >;
    #local MedioPataTrasera     =
                < -LargoSoporte/2, AltoBase, -LargoSoporte/2 >;
    #local FinPataTrasera       =
                < -1.2*LargoSoporte/2, AltoPataTrasera, -LargoSoporte/2 >;
    #local C            = 0;
    #while ( C < 2 )
      union       {
        object      {
          MSCS_AnilloTriplePunto(
            InicioPataTrasera, MedioPataTrasera, FinPataTrasera,
            GruesoPataTrasera, GruesoPataTrasera, false )
        }
        object      {
          MSCS_AnilloTriplePunto(
            InicioPataTrasera, MedioPataTrasera-0.75*GruesoPataTrasera*x,
            FinPataTrasera,
            GruesoPataTrasera, GruesoPataTrasera, false )
        }

        #if ( C = 0 )
          scale     <1,1,-1>
        #end
      }
      #local C          = C+1;
    #end
    object      {
      PataDelantera
      translate         +LargoSoporte/2*x+LargoSoporte/2*z
    }
    object      {
      PataDelantera
      translate         +LargoSoporte/2*x-LargoSoporte/2*z
    }
    object      {
      AdornoFinPataTrasera
      translate         FinPataTrasera
    }
    object      {
      AdornoFinPataTrasera
      translate         FinPataTrasera
      scale     <1,1,-1>
    }
    // AdornoPataTrasera
    #local AltoDecoradoDelantero        = 157*L;
    #local C            = 0;
    #while ( C < 2 )
      lathe         {
        cubic_spline
        #local AltoSor    = LargoSoporte/2;
        #local FactorSor  = < GruesoPataDelantera/3, AltoSor >;
        7,
        <+0.00,-0.10 >*FactorSor,
        <+0.40,+0.00 >*FactorSor,
        <+1.00,+0.76 >*FactorSor,
        <+0.80,+0.86 >*FactorSor,
        <+1.00,+0.93 >*FactorSor,
        <+0.80,+1.00 >*FactorSor,
        <+0.00,+1.10 >*FactorSor
        rotate          90*x
        translate       LargoSoporte/2*x+AltoDecoradoDelantero*y-AltoSor*z
        #if ( C = 0 )
          scale <1,1,-1>
        #end
      }
      #local C          = C+1;
    #end
    #local GruesoTabla          = 12*L;
    #local AltoTabla            = 370*L;
    #local LargoTabla           = LargoSoporte-GruesoPataTrasera;
    #local AlturaTabla          = AltoBase+53*L;
    #local AltoAntesAbertura    = 50*L;
    #local AltoAberturaTabla    = 271*L;
    #local AnchoAbertura        = 21*L;
    #local AnchoSeparadorAbertura       = 25*L;
    #local AltoFinTabla               =
                AltoTabla-AltoAntesAbertura-AltoAberturaTabla;
    union       {
      difference        {
        box     {
          < -GruesoTabla/2,    0       , -LargoTabla/2  >,
          < +GruesoTabla/2,+0.9*AltoTabla  , +LargoTabla/2  >
        }
        box     {
          < -GruesoTabla, AltoAntesAbertura, -LargoTabla/2 >,
          < +GruesoTabla, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura >
        }
        box     {
          < -GruesoTabla, AltoAntesAbertura, +LargoTabla/2 >,
          < +GruesoTabla, AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura >
        }
        box     {
          < -GruesoTabla, AltoAntesAbertura,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
          < +GruesoTabla, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >
        }
      }
      object            {
        MSCS_DecoradoBajo( LargoTabla, GruesoTabla, AltoFinTabla )
        scale           <1,-1,1>
        rotate          90*y
        translate       AltoTabla*y
      }
      // Tela
      union             {
        box             {
          < +GruesoTabla/2      , AltoAntesAbertura,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
          < +3*GruesoTabla/2      , AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >
        }
        difference      {
          union         {
            cylinder    {
              < +GruesoTabla/2, AltoAntesAbertura,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
              < +GruesoTabla/2, AltoAntesAbertura,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
                GruesoTabla
            }
            cylinder    {
              < +GruesoTabla/2, AltoAntesAbertura,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
                GruesoTabla
            }
            cylinder    {
              < +GruesoTabla/2, AltoAntesAbertura,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
                GruesoTabla
            }
            sphere      {
              < +GruesoTabla/2, AltoAntesAbertura,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
                GruesoTabla
            }
            sphere      {
              < +GruesoTabla/2, AltoAntesAbertura,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
                GruesoTabla
            }
            sphere      {
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
                GruesoTabla
            }
            sphere      {
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
                GruesoTabla
            }
            MSCS_SweepTriplePunto(
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
              < +GruesoTabla/2, 1.5*AltoAntesAbertura+AltoAberturaTabla,
                0.0 >,
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
              GruesoTabla, false )
            MSCS_AnilloTriplePunto(
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                +LargoTabla/2-AnchoAbertura-AnchoSeparadorAbertura >,
              < +GruesoTabla/2, 1.25*AltoAntesAbertura+AltoAberturaTabla,
                0.0 >,
              < +GruesoTabla/2, AltoAntesAbertura+AltoAberturaTabla,
                -LargoTabla/2+AnchoAbertura+AnchoSeparadorAbertura >,
              2*GruesoTabla, 2*GruesoTabla, false )
          }
          plane         {
            x           , +GruesoTabla/2
          }
        }
        texture         {
          TexturaTela
        }
      }
      rotate            +2.0*z
      translate         AlturaTabla*y-( LargoSoporte/2+GruesoPataTrasera/2 )*x
    }
    union             {
      #local ExpansionDelanteraAsiento        = GruesoAsiento/20;
      #local Asiento_P1       =
                < -LargoSoporte/2,
                  +AltoBase+GruesoAsiento/2,
                  +LargoSoporte/2-GruesoPataTrasera/2-GruesoAsiento/2 >;
      #local Asiento_P2       =
                < -LargoSoporte/2+GruesoPataTrasera/2+GruesoAsiento/2,
                  +Asiento_P1.y,
                  +Asiento_P1.z >;
      #local Asiento_P3       =
                < +Asiento_P2.x,
                  +Asiento_P1.y,
                  +LargoSoporte/2 >;
      #local Asiento_P4       =
                < +LargoSoporte/2+ExpansionDelanteraAsiento,
                  +Asiento_P1.y,
                  +Asiento_P3.z+ExpansionDelanteraAsiento >;
      prism           {
          +AltoBase,
          +AltoBase+GruesoAsiento,
          9,
          < Asiento_P1.x, Asiento_P1.z >,
          < Asiento_P2.x, Asiento_P2.z >,
          < Asiento_P3.x, Asiento_P3.z >,
          < Asiento_P4.x, Asiento_P4.z >,
          < Asiento_P4.x,-Asiento_P4.z >,
          < Asiento_P3.x,-Asiento_P3.z >,
          < Asiento_P2.x,-Asiento_P2.z >,
          < Asiento_P1.x,-Asiento_P1.z >,
          < Asiento_P1.x, Asiento_P1.z >
      }
      cylinder          {
        Asiento_P1, Asiento_P2, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P2, Asiento_P3, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P3, Asiento_P4, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P4, Asiento_P4*<1,1,-1>, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P4*<1,1,-1>, Asiento_P3*<1,1,-1>, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P3*<1,1,-1>, Asiento_P2*<1,1,-1>, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P2*<1,1,-1>, Asiento_P1*<1,1,-1>, GruesoAsiento/2
      }
      cylinder          {
        Asiento_P1*<1,1,-1>, Asiento_P1, GruesoAsiento/2
      }
      sphere            {
        Asiento_P1*<1,1,+1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P2*<1,1,+1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P3*<1,1,+1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P4*<1,1,+1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P1*<1,1,-1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P2*<1,1,-1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P3*<1,1,-1>, GruesoAsiento/2
      }
      sphere            {
        Asiento_P4*<1,1,-1>, GruesoAsiento/2
      }
      texture         {
          TexturaTela
      }
    }
    texture     {
      TexturaMadera
    }
  }
#end

#macro MSCS_Mesa()      
object        {
  MSCS_MacroMesa( MSCS_TexturaMaderaDefault )
}
#end

#macro MSCS_Silla()
object        {
  MSCS_MacroSilla( MSCS_TexturaMaderaDefault, MSCS_TexturaTelaDefault )
}
#end

#macro MSCS_MesaSillas()        
union {  
  #local L                              = MSCS_L;
  #local LargoBaseMesa                  = 643*L;
  #local DiametroBase                   = 686*L;
  object        {
    MSCS_Mesa()
  }
  object        {
    MSCS_Silla()
    rotate      -90*y
    rotate      1*y
    translate   -DiametroBase/2*z+3*LargoBaseMesa/10*x
  }
  object        {
    MSCS_Silla()
    rotate      -90*y
    rotate      -2*y
    translate   -DiametroBase/2*z-3*LargoBaseMesa/10*x
  }
  object        {
    MSCS_Silla()
    rotate      +90*y
    rotate      1.5*y
    translate   +DiametroBase/2*z+3*LargoBaseMesa/10*x
  }
  object        {
    MSCS_Silla()
    rotate      +90*y
    rotate      -0.5*y
    translate   +DiametroBase/2*z-3*LargoBaseMesa/10*x
  }
  object        {
    MSCS_Silla()
    rotate      1*y
    translate   -DiametroBase/2*x-LargoBaseMesa/2*x
  }
  object        {
    MSCS_Silla()
    rotate      180*y
    rotate      -1*y
    translate   +DiametroBase/2*x+LargoBaseMesa/2*x
  }
}
#end


