// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 19 abril 2011
//                
// Mis dibujos estn en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// La macro RCPS_Capullo( Semilla, TotalHojas )
// genera un objeto con
// las siguientes caracteristicas
// Base de Capullo en origen
// orientado hacia y+
// Alto Capullo         : 70*L en y
// Radio Capullo        : 25*L aprox
// Largo Tallo          : 170*L aprox
// Radio Tallo          : 3.0*L
// Final Tallo          : Aleatorio en RCPS_FinalTallo
//              El vector 3D se genera automaticamente con la macro
// Los parametros serian
//      Semilla         : Numero seed para aleatoriedad
//                        misma Semilla implica misma flor
//      TotalHojas      : Numero de hojas en el tallito
//                        a partir de 0
//
// La macro RCPS_Rosa( Semilla, TotalHojas )
// genera un objeto con
// las siguientes caracteristicas
// Base de Capullo en origen
// orientado hacia y+
// Alto Rosa            : 37*L en y
// Radio Rosa           : 25*L aprox
// Largo Tallo          : 170*L aprox
// Radio Tallo          : 1.5*L
// Final Tallo          : Aleatorio en RCPS_FinalTallo
//              El vector 3D se genera automaticamente con la macro
// Los parametros serian
//      Semilla         : Numero seed para aleatoriedad
//                        misma Semilla implica misma flor
//      TotalHojas      : Numero de hojas en el tallito
//                        a partir de 0
//
// Los objetos tambien se pueden generar via una macro principal
// #macro   RCPS_FlorPlasticaColorVariado
//        ( Estilo, Semilla, TexturaPrincipal,
//              TexturaSecundaria, TexturaHoja, TexturaTallo, TotalHojas  )
//  Existen dos estilos predefinidos
//      Estilo                  : RCPS_EstiloCapullo y RCPS_EstiloRosa
//      Semilla                 : Numero seed para aleatoriedad
//      TexturaPrincipal        : Se aplica a los petalos
//      TexturaSecundaria       : Se aplica a los estambres
//      TexturaHojas            : Se aplica a las hojas
//      TexturaTallo            : Se aplica al tallito
//      TotalHojas              : A partir de 0, controla el total
//              de hojas en el tallito
//
// Las siguientes variables no deberian modificarse
// RCPS_TexturaPrincipalCapullo
//      Define la textura utilizada en los petalos del capullo
// RCPS_TexturaSecundariaCapullo
//      Define la textura utilizada en los estambres del capullo
// RCPS_TexturaHojaCapullo
//      Define la textura utilizada en las hojas del capullo
// RCPS_TexturaTalloCapullo
//      Define la textura utilizada en el tallo del capullo
// RCPS_TexturaPrincipalRosa
//      Define la textura utilizada en los petalos de la rosa
// RCPS_TexturaSecundariaRosa
//      Define la textura utilizada en los estambres de la rosa
// RCPS_TexturaHojaRosa
//      Define la textura utilizada en las hojas de la rosa
// RCPS_TexturaTalloRosa
//      Define la textura utilizada en el tallo de la rosa
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare RCPS_POV3_1         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
// #declare RCPS_TexturaPrincipalCapulloDefault         = texture ...
//      Define la textura utilizada en los petalos del capullo
// #declare RCPS_TexturaSecundariaCapulloDefault        = texture ...
//      Define la textura utilizada en los estambres del capullo
// #declare RCPS_TexturaHojaCapulloDefault              = texture ...
//      Define la textura utilizada en las hojas del capullo
// #declare RCPS_TexturaTalloCapulloDefault             = texture ...
//      Define la textura utilizada en el tallo del capullo
// #declare RCPS_TexturaPrincipalRosaDefault            = texture ...
//      Define la textura utilizada en los petalos de la rosa
// #declare RCPS_TexturaSecundariaRosaDefault           = texture ...
//      Define la textura utilizada en los estambres de la rosa
// #declare RCPS_TexturaHojaRosaDefault                 = texture ...
//      Define la textura utilizada en las hojas de la rosa
// #declare RCPS_TexturaTalloRosaDefault                = texture ...
//      Define la textura utilizada en el tallo de la rosa
//
// Para colocarlo simplemente
// #include "RCPS.inc"
// object { RCPS_Rosa( 1232, 4 ) }
//
// Otro ejemplo con modificador
// #include "RCPS.inc"
// #declare RCPS_TexturaPrincipalRosaDefault    = texture       {
//   average
//   texture_map        {
//     [ 0.5 RCPS_TexturaPrincipalRosa    ]
//     [ 0.5 RCPS_TexturaPrincipalCapullo ]
//   }
// }
// object       { RCPS_Rosa( 1232, 4 ) }
//

#include "RCPS_AUX.inc"
#include "colors.inc"

#if ( version < 3.2 )
  #ifndef( RCPS_POV3_1 )
    #declare RCPS_POV3_1        = on;
  #end
#else
  #ifndef( RCPS_POV3_1 )
    #declare RCPS_POV3_1        = off;
  #end
#end

#declare RCPS_L                 = 0.001;

#declare RCPS_EstiloCapullo     = 2;
#declare RCPS_EstiloRosa        = 3;

#declare RCPS_TexturaPrincipalCapullo     = texture       {  
  #if ( RCPS_POV3_1 )
    pigment     {
      onion  
      sine_wave   
      turbulence        1
      scale     0.040
      pigment_map       {
        [ 0.0  Red                      ]
        [ 1.0  rgb ( 2*Red+Yellow )/3                  ]
      } 
    }
  #else
    pigment     {
      onion  
      sine_wave   
      turbulence        1
      scale     0.040
      pigment_map       {
        [ 0.0  Red                      ]
        [ 1.0  rgb ( 2*Red+Yellow )/3                  ]
      } 
    }
    normal              {
      average
      normal_map        {
        [ 0.4 facets                    ]
        [ 0.6 bumps  scale      0.1     ]
      }
    }
  #end
}

#declare RCPS_TexturaSecundariaCapullo    = texture       {
  #if ( RCPS_POV3_1 )
    pigment       { Yellow }
  #else
    pigment     { 
      cells
      rotate    20
      scale     0.001
      turbulence        2
      pigment_map       {
        [ 0.0 Yellow ]
        [ 1.0 Coral  ]
      }
    }
    normal      {
      cells
      rotate    20
      scale     0.001
    }
  #end
}

#declare RCPS_TexturaHojaCapullo          = 
    texture     {
      pigment     {
        checker 
        pigment   {
          gradient        z 
          turbulence      0.3 
          rotate          30*y
          sine_wave
          scale           0.001
          pigment_map     {
            [ 0.0 ForestGreen ]
            [ 1.0 MediumForestGreen ]
          }
        }
        pigment   {
          gradient        z
          turbulence      0.3
          rotate          -30*y
          sine_wave
          scale           0.002
          pigment_map     {
            [ 0.0 ForestGreen ]
            [ 1.0 MediumForestGreen ]
          }
        }
      }   
      normal            {
        checker
        normal   {
          gradient        z 
          turbulence      0.3 
          rotate          30*y
          sine_wave
          scale           0.001
        }
        normal   {
          gradient        z 
          turbulence      0.3 
          rotate          -30*y
          sine_wave
          scale           0.001
        }
      }  
    }
    texture     {
      pigment     {
        gradient          x
        turbulence        0.25
        scallop_wave
        scale             0.02
        pigment_map       {
          [ 0.0 ForestGreen  ]
          [ 1.0 rgbt 1       ]
        }
      } 
      normal    {
        gradient          x
        translate         0.5*x
        turbulence        0.25
        sine_wave
        scale             0.01
      }
    }

#declare RCPS_TexturaTalloCapullo         = texture       {
    pigment     {
      gradient  x  
      turbulence        0.5
      scallop_wave
      scale     0.003
      rotate    10*z
      pigment_map       {
        [ 0.0 ForestGreen       ]
        [ 1.0 MediumForestGreen ]
      } 
    }
}

#ifndef ( RCPS_TexturaPrincipalCapulloDefault )
  #declare RCPS_TexturaPrincipalCapulloDefault            = texture       {
    RCPS_TexturaPrincipalCapullo
  }
#end

#ifndef ( RCPS_TexturaSecundariaCapulloDefault )
  #declare RCPS_TexturaSecundariaCapulloDefault           = texture       {
    RCPS_TexturaSecundariaCapullo
  }
#end

#ifndef ( RCPS_TexturaHojaCapulloDefault )
  #declare RCPS_TexturaHojaCapulloDefault                 = texture       {
    RCPS_TexturaHojaCapullo
  }
#end

#ifndef ( RCPS_TexturaTalloCapulloDefault )
  #declare RCPS_TexturaTalloCapulloDefault                = texture       {
    RCPS_TexturaTalloCapullo
  }
#end

#declare RCPS_TexturaPrincipalRosa     = texture       {
  #if ( RCPS_POV3_1 )
    pigment     {
      onion  
      sine_wave   
      turbulence        1
      scale     0.030
      pigment_map       {
        [ 0.0  Red                      ]
        [ 1.0  rgb ( Red+2*Yellow )/3                  ]
      } 
    }
  #else
    pigment     {
      onion  
      sine_wave   
      turbulence        1
      scale     0.030
      pigment_map       {
        [ 0.0  Red                      ]
        [ 1.0  rgb ( Red+2*Yellow )/3                  ]
      } 
    }
    normal              {
      average
      normal_map        {
        [ 0.4 facets                    ]
        [ 0.6 bumps  scale      0.1     ]
      }
    }
  #end
}

#declare RCPS_TexturaSecundariaRosa    = texture       {
  #if ( RCPS_POV3_1 )
    pigment       { Yellow }
  #else
    pigment     { 
      cells
      rotate    20
      scale     0.001
      turbulence        2
      pigment_map       {
        [ 0.0 Yellow ]
        [ 1.0 Coral  ]
      }
    }
    normal      {
      cells
      rotate    20
      scale     0.001
    }
  #end
}

#declare RCPS_TexturaHojaRosa          =
    texture     {
      pigment     {
        checker 
        pigment   {
          gradient        z 
          turbulence      0.3 
          rotate          30*y
          sine_wave
          scale           0.001
          pigment_map     {
            [ 0.0 ForestGreen ]
            [ 1.0 MediumForestGreen ]
          }
        }
        pigment   {
          gradient        z
          turbulence      0.3
          rotate          -30*y
          sine_wave
          scale           0.002
          pigment_map     {
            [ 0.0 ForestGreen ]
            [ 1.0 MediumForestGreen ]
          }
        }
      }   
      normal            {
        checker
        normal   {
          gradient        z 
          turbulence      0.3 
          rotate          30*y
          sine_wave
          scale           0.001
        }
        normal   {
          gradient        z 
          turbulence      0.3 
          rotate          -30*y
          sine_wave
          scale           0.001
        }
      }  
    }
    texture     {
      pigment     {
        gradient          x
        turbulence        0.25
        scallop_wave
        scale             0.02
        pigment_map       {
          [ 0.0 ForestGreen  ]
          [ 1.0 rgbt 1       ]
        }
      } 
      normal    {
        gradient          x
        translate         0.5*x
        turbulence        0.25
        sine_wave
        scale             0.01
      }
    }

#declare RCPS_TexturaTalloRosa         = texture       {
    pigment     {
      gradient  x  
      turbulence        0.5
      scallop_wave
      scale     0.003
      rotate    10*z
      pigment_map       {
        [ 0.0 ForestGreen       ]
        [ 1.0 MediumForestGreen ]
      } 
    }
}

#ifndef ( RCPS_TexturaPrincipalRosaDefault )
  #declare RCPS_TexturaPrincipalRosaDefault            = texture       {
    RCPS_TexturaPrincipalRosa
  }
#end

#ifndef ( RCPS_TexturaSecundariaRosaDefault )
  #declare RCPS_TexturaSecundariaRosaDefault           = texture       {
    RCPS_TexturaSecundariaRosa
  }
#end

#ifndef ( RCPS_TexturaHojaRosaDefault )
  #declare RCPS_TexturaHojaRosaDefault                 = texture       {
    RCPS_TexturaHojaRosa
  }
#end

#ifndef ( RCPS_TexturaTalloRosaDefault )
  #declare RCPS_TexturaTalloRosaDefault                = texture       {
    RCPS_TexturaTalloRosa
  }
#end

#macro RCPS_PuntoAleatorio( NuevoPunto, Desplazado, Aleatorio )
  #local NuevoPunto     = NuevoPunto+
     Desplazado*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >;
#end

#macro   RCPS_FlorPlasticaColorVariado
        ( Estilo, Semilla, TexturaPrincipal,
             TexturaSecundaria, TexturaHoja, TexturaTallo, TotalHojas  )
  #local Aleatorio      = seed( Semilla );                   
  #local L                              = RCPS_L;
  #switch ( Estilo )
    #case ( RCPS_EstiloCapullo )
      #local AlturaPetalo               = 57*L;
      #local AnchoPetalo                = 36*L;
      #local RadialPetalo               = 18*L;
      #local GruesoLaminar              = 0.2*L;
      #local PuntoCero                  = <0,0,0>;
      #local PuntoCentro                = < 0, AlturaPetalo/2, -RadialPetalo>;
      #local PuntoAlto                  =
                < 0, AlturaPetalo, -0.8*RadialPetalo >;
      #local PuntoAlto2                 =
                < 0.5*AnchoPetalo/2, 0.95*AlturaPetalo, -0.80*RadialPetalo >;
      #local LateralCentro              =
                < AnchoPetalo/2, AlturaPetalo/2, -RadialPetalo>;
      #declare PetaloMitad              = union         {
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoCentro, PuntoCero, LateralCentro, AnchoPetalo,
                GruesoLaminar, true, true, true, true )
        }
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoAlto, PuntoCentro, LateralCentro, AnchoPetalo,
                GruesoLaminar, true, true, true, true )
        }
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoAlto2, PuntoAlto, LateralCentro, AnchoPetalo,
                GruesoLaminar, false, true, false, true )
        }
        #local PuntoPiv         = ( PuntoAlto+LateralCentro )/2*<1.15,1,1.2>;
        object  {
          RCPS_SweepTriplePunto
            ( PuntoAlto, PuntoPiv, LateralCentro,
                        AnchoPetalo/35, false )
        }
      }
      #local Petalo                     = union         {
        object          {
          PetaloMitad
        }
        object          {
          PetaloMitad
          scale         <-1,1,1>
        }
      }
      #local AnguloSelf         = 10;
      union                     {
        #local C                = 0;
        #local PetalosFrontales = 3;
        #while ( C < PetalosFrontales )
          object  {
            Petalo
            rotate      C/PetalosFrontales*360*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          object  {
            Petalo
            scale       <0.8,1.2,0.8>
            rotate      1/( 2*PetalosFrontales )*360*y
            rotate      C/PetalosFrontales*360*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          #local C              = C+1;
        #end
        sphere                  {
          0.25*AlturaPetalo*y   , 0.20*AlturaPetalo
        }
        // estambres
        #local RCPS_Estambre    = union         {
          cylinder              {
            0.25*AlturaPetalo*y , 0.85*AlturaPetalo*y,
            0.005*AlturaPetalo
          }
          sphere                {
            0                   , 0.05*AlturaPetalo
            scale               <1,0.8,0.2>
            rotate
                30*<rand( Aleatorio ),rand( Aleatorio),rand( Aleatorio )>
            translate           0.75*AlturaPetalo*y
          }
        }
        union                   {
          #local TotalEstambres   = 6;
          #local C                = 0;
          #while ( C < TotalEstambres )
            object                {
              RCPS_Estambre
              rotate            360*rand( Aleatorio )*y
              translate      -0.1*AlturaPetalo*rand( Aleatorio )*y
              rotate
  30*<-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ) >
            }
            #local C            = C+1;
          #end
          texture               {
            TexturaSecundaria
          }
        }
        #local RadioTallo       = 3.0*L;
        #local LargoTallo       = 3*AlturaPetalo;
        #local TalloAux         = <0,-0.2*LargoTallo,0>;
        #local Tallo1           =
            LargoTallo*< 0.2*rand( Aleatorio ), -1, 0.2*rand( Aleatorio) >;
        object                  {
          RCPS_SweepTriplePunto
          ( PuntoCero, TalloAux, Tallo1, RadioTallo, true )
          translate             0.2*AlturaPetalo*y
          texture               {
            TexturaTallo
          }
        }
        #declare RCPS_FinalTallo        = Tallo1+0.2*AlturaPetalo*y;
        // hojas
        union                   {
          #local RadialHojas    = <0,+0.2*RadialPetalo,-RadialPetalo>;
          #local LateralHojas   = <0.2*RadialPetalo,0,0>;
          #local LateralHojasS  = LateralHojas*<-1,1,1>;
          #local TotalHojitas   = 10;
          #local C              = 0;
          #local Hojitas        = object        {
             RCPS_TrianguloEsfericoTriplePunto
             ( RadialHojas, LateralHojasS, LateralHojas,
                        0.6*RadialPetalo, GruesoLaminar, false )
             texture    {
               TexturaHoja
             }
             rotate    +30*x
          }
          #while ( C < TotalHojitas )
            object              {
              Hojitas
              rotate
  20*<-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio )>
              rotate            C/TotalHojitas*360*y
            }
            #local C            = C+1;
          #end
          cone                  {
            -0.25*AlturaPetalo*y  , 0,
            0.15*AlturaPetalo*y   , 0.10*AlturaPetalo 
            translate           -0.15*AlturaPetalo*y
          }
          #local Base1          = <0,-0.2*AlturaPetalo,0>;
          #local MedioHoja1     = <0,-0.1*AlturaPetalo,0.4*AlturaPetalo>;
          #local MediaHojaA     = vaxis_rotate( MedioHoja1, y, -25 );
          #local MediaHojaB     = vaxis_rotate( MedioHoja1, y,  25 );
          #local HojaFinal1     = <0,-0.2*AlturaPetalo,0.6*AlturaPetalo>;
          #if ( TotalHojas >= 1 )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true ) 
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -10*x
            rotate      -10*z
            rotate      90*y
            translate   -0.25*( 1+rand( Aleatorio ) )*AlturaPetalo*y 
            rotate      360*rand( Aleatorio )*y
          }
          #end
          #if ( TotalHojas >= 2 )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -40*x
            rotate      +10*z
            rotate      250*y
            translate   -0.3*( 1+rand( Aleatorio ) )*AlturaPetalo*y
            rotate      360*rand( Aleatorio )*y
          }
          #end
          #local C              = 2;
          #while ( C < TotalHojas )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true ) 
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -10*x
            rotate      -10*z
            rotate      90*y
            translate   -0.6*( 0.5+rand( Aleatorio ) )*AlturaPetalo*y 
            rotate      360*rand( Aleatorio )*y
          }
            #local C            = C+1;
          #end
          texture               {
            TexturaHoja
          }
        }
        texture                 {
          TexturaPrincipal
        }
      }
    #break
    #case ( RCPS_EstiloRosa )
      #local AlturaPetalo               = 57*L;
      #local AnchoPetalo                = 36*L;
      #local RadialPetalo               = 18*L;
      #local GruesoLaminar              = 0.2*L;
      #local PuntoCero                  = <0,0,0>;
      #local PuntoCentro                = < 0, AlturaPetalo/2, -RadialPetalo>;
      #local PuntoAlto                  =
                < 0, AlturaPetalo, -0.8*RadialPetalo >;
      #local PuntoAlto2                 =
                < 0.5*AnchoPetalo/2, 0.95*AlturaPetalo, -0.80*RadialPetalo >;
      #local LateralCentro              =
                < AnchoPetalo/2, AlturaPetalo/2, -RadialPetalo>;
      #declare PetaloMitad              = union         {
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoCentro, PuntoCero, LateralCentro, AnchoPetalo,
                GruesoLaminar, true, true, true, true )
        }
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoAlto, PuntoCentro, LateralCentro, AnchoPetalo,
                GruesoLaminar, true, true, true, true )
        }
        object  {
          RCPS_SegmentoTrianguloEsfericoTriplePunto
          ( PuntoAlto2, PuntoAlto, LateralCentro, AnchoPetalo,
                GruesoLaminar, false, true, false, true )
        }
        #local PuntoPiv         = ( PuntoAlto+LateralCentro )/2*<1.15,1,1.2>;
        object  {
          RCPS_SweepTriplePunto
            ( PuntoAlto, PuntoPiv, LateralCentro,
                        AnchoPetalo/35, false )
        }
        scale           < 1.0, 0.2, 1.5 >
      }
      #local Petalo                     = union         {
        object          {
          PetaloMitad
        }
        object          {
          PetaloMitad
          scale         <-1,1,1>
        }
      }
      #local AnguloSelf         = 10;
      union                     {
        #local C                = 0;
        #local PetalosFrontales = 5;
        #while ( C < PetalosFrontales )
          object  {
            Petalo
            rotate      C/PetalosFrontales*360*y
            scale       2.5*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          object  {
            Petalo
            scale       <0.8,1.2,0.8>
            scale       <1.0,1.6,1.0>
            scale       1.5*y
            rotate      1/( 2*PetalosFrontales )*360*y
            rotate      C/PetalosFrontales*360*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          object  {
            Petalo
            scale       <0.6,2.8,0.6>
            rotate      1/( 2*PetalosFrontales )*360*y
            rotate      ( C+0.75)/PetalosFrontales*360*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          object  {
            Petalo
            scale       <0.3,3.2,0.3>
            rotate      1/( 2*PetalosFrontales )*360*y
            rotate      ( C+0.5 )/PetalosFrontales*360*y
            rotate
       AnguloSelf*< rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >
          }
          #local C              = C+1;
        #end

        //  Estambres
        #local RCPS_Estambre    = union         {
          cylinder              {
            0.25*AlturaPetalo*y , 0.65*AlturaPetalo*y,
            0.010*AlturaPetalo
          }
          sphere                {
            0                   , 0.05*AlturaPetalo
            scale               <1,0.8,0.2>
            scale               0.5
            rotate
                30*<rand( Aleatorio ),rand( Aleatorio),rand( Aleatorio )>
            translate           0.55*AlturaPetalo*y
          }
        }
        union                   {
          #local TotalEstambres   = 6;
          #local C                = 0;
          #while ( C < TotalEstambres )
            object                {
              RCPS_Estambre
              rotate            360*rand( Aleatorio )*y
              translate      -0.1*AlturaPetalo*rand( Aleatorio )*y
              rotate
  30*<-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ) >
            }
            #local C            = C+1;
          #end
          texture               {
            TexturaSecundaria
          }
        }
        
        #local RadioTallo       = 1.5*L;
        #local LargoTallo       = 3*AlturaPetalo;
        #local TalloAux         = <0,-0.2*LargoTallo,0>;
        #local Tallo1           =
            LargoTallo*< 0.2*rand( Aleatorio ), -1, 0.2*rand( Aleatorio) >;
        object                  {
          RCPS_SweepTriplePunto
          ( PuntoCero, TalloAux, Tallo1, RadioTallo, true )
          translate             0.2*AlturaPetalo*y
          texture               {
            TexturaTallo
          }
        }
        #declare RCPS_FinalTallo        = Tallo1+0.2*AlturaPetalo*y;
        // hojas
        union                   {
          #local RadialHojas    = <0,+0.05*RadialPetalo,-1.5*RadialPetalo>;
          #local LateralHojas   = <0.2*RadialPetalo,0,0>;
          #local LateralHojasS  = LateralHojas*<-1,1,1>;
          #local TotalHojitas   = 10;
          #local C              = 0;
          #local Hojitas        = object        {
             RCPS_TrianguloEsfericoTriplePunto
             ( RadialHojas, LateralHojasS, LateralHojas,
                        1.5*RadialPetalo, GruesoLaminar, false ) 
             texture            {
               TexturaHoja
             }
             rotate    +10*x
          }
          #while ( C < TotalHojitas )
            object              {
              Hojitas    
              rotate
  20*<-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio ),-0.5+rand( Aleatorio )>
              rotate            C/TotalHojitas*360*y
            }
            #local C            = C+1;
          #end
          difference              {
            cone                  {
              -0.25*AlturaPetalo*y  , 0,
              0.15*AlturaPetalo*y   , 0.070*AlturaPetalo
            }
            plane                 {
              -y   ,0
              rotate      +30*x
              translate   0.15*AlturaPetalo*y-0.070*AlturaPetalo*z
              rotate      90*y
            }
            translate         -0.15*AlturaPetalo*y
            texture             {
              TexturaTallo
            }
          }
          #local Base1          = <0,-0.2*AlturaPetalo,0>;
          #local MedioHoja1     = <0,-0.1*AlturaPetalo,0.4*AlturaPetalo>;
          #local MediaHojaA     = vaxis_rotate( MedioHoja1, y, -25 );
          #local MediaHojaB     = vaxis_rotate( MedioHoja1, y,  25 );
          #local HojaFinal1     = <0,-0.2*AlturaPetalo,0.6*AlturaPetalo>;
          #if ( TotalHojas >= 1 )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -10*x
            rotate      -10*z
            rotate      90*y
            translate   -0.3*( 1+rand( Aleatorio ) )*AlturaPetalo*y
            rotate      360*y*rand( Aleatorio )
          }
          #end
          #if ( TotalHojas >= 2 )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -40*x
            rotate      +10*z
            rotate      250*y
            translate   -0.4*( 1+rand( Aleatorio ) )*AlturaPetalo*y
            rotate      360*y*rand( Aleatorio )
          }
          #end
          #local C      = 2;
          #while ( C < TotalHojas )
          union                 {
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( Base1, MediaHojaB, MediaHojaA, 0.5*AlturaPetalo,
                        GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            object              {
              RCPS_TrianguloEsfericoTriplePunto
                ( HojaFinal1, MediaHojaA, MediaHojaB, 0.55*AlturaPetalo,
                        2.5*GruesoLaminar, true )
              texture           {
                TexturaHoja
              }
            }
            translate   0.2*AlturaPetalo*y
            rotate      -10*x
            rotate      -10*z
            rotate      90*y
            translate   -0.6*( 0.5+rand( Aleatorio ) )*AlturaPetalo*y
            rotate      360*y*rand( Aleatorio )
          }
            #local C    = C+1;
          #end
          texture               {
            TexturaHoja
          }
        }
        texture                 {
          TexturaPrincipal
        }
      }
    #break
  #end
#end

#macro RCPS_Capullo( Semilla, TotalHojas )
  object        {
    RCPS_FlorPlasticaColorVariado( RCPS_EstiloCapullo, Semilla,
        RCPS_TexturaPrincipalCapulloDefault,
        RCPS_TexturaSecundariaCapulloDefault,
        RCPS_TexturaHojaCapulloDefault,
        RCPS_TexturaTalloCapulloDefault, TotalHojas )
  }
#end

#macro RCPS_Rosa( Semilla, TotalHojas )
  object        {
    RCPS_FlorPlasticaColorVariado( RCPS_EstiloRosa, Semilla,
        RCPS_TexturaPrincipalRosaDefault,
        RCPS_TexturaSecundariaRosaDefault,
        RCPS_TexturaHojaRosaDefault,
        RCPS_TexturaTalloRosaDefault, TotalHojas )
  }
#end



