// This file is licensed under the terms of the CC-LGPL.
//
// Autor  : Rafael Angel Campos Vargas
// Correo : RofoelCompos@hotmail.com  
// Apdo. 964-1250 Escazu, San Jose, Costa Rica
// dedicado a Jesus y Maria...
//
// En este momento estoy creando un programa
// de animacion LibreN3D para FreeDOS con el compilador FreePascal
// falta mucho... 9 mayo 2011
//                
// Mis dibujos estan en unidades L (Lisa)
// 1 L equivale a 0.055063 pulgadas 
// definido como 0.001 para POVRAY 
//
// La macro RDVM_Rosario()
// crea un Rosario catolico para decoracion de pared
// Su posicion inicial descansa en el plano XY, hacia z-;
// aproximadamente centrado en el origen.
// Sus dimensiones son ligeramente superiores a
// Ancho Frontal        = 600*L
// Alto                 = 500*L
// Profundidad          = 21*L
//
// El objeto puede generarse via una macro principal de texturas
// #macro RDVM_RosarioDevocionVirgenMaria
//          ( Semilla, Tension1, Tension2, Angulo2,
//                TexturaCuentaBasica, TexturaMetal,
//                TexturaMadera, MaterialCruz, MaterialCruzMenor,
//                TexturaMedalla )
//      Semilla                 : para aleatoriedad, misma semilla,
//              misma estructura de rosario.
//      Tension1                : default es 0.5.  Controla la tension
//              en la cadena superior del rosario.  Mayor tension,
//              eleva el centro de la cadena.  En fisica seria el valor
//              proporcional ( Tension/Densidad ).
//      Tension2                : default es 0.5.  Controla la tension
//              en la cadena inferior del rosario, sin contar el angulo.
//      Angulo2                 : default es 15 grados.  Angulo aproximado
//              que forma el triangulo de madera con la cadena.
//      TexturaCuentaBasica     : default es RDVM_DefaultTexturaCuentaBasica.
//              Textura a aplicar en las bolitas del rosario.
//      TexturaMetal            : default es RDVM_DefaultTexturaMetal.
//              Textura a aplicar en las cadenas y la decoracion de las
//              bolitas del rosario.
//      TexturaMadera           : default es RDVM_DefaultTexturaMadera.
//              Textura a aplicar en el triangulo de madera que cierra
//              el rosario.
//      MaterialCruz            : default es RDMV_DefaultMaterialCruz.
//              Material a aplicar en la cruz inferior.
//      MaterialCruzMenor       : default es RDVM_DefaultMaterialCruz2.
//              Material a aplicar en la crucecita decorativo  del triangulo.
//      TexturaMedalla          : default es RDVM_DefaultTexturaMedalla.
//              Textura a aplicar en la medallita que sirve de fondo
//              en el triangulo de madera.
//
// Las siguientes variables no deberian modificarse
// RDVM_PuntoCruz
//      Establece la posicion superior de la cruz.
//      Podria ser util ante un eventual cambio de crucifijo.
// RDVM_TexturaCuentaBasica
//      Textura a aplicar en las bolitas del rosario.
// RDVM_TexturaMetalica
//      Textura a aplicar en las cadenas y la decoracion de las
//      bolitas del rosario.
// RDVM_TexturaMadera
//      Textura a aplicar en el triangulo de madera que cierra el rosario.
// RDVM_MaterialCruz
//      Material a aplicar en la cruz principal.
// RDVM_MaterialCruz2
//      Material a aplicar en la crucecita decorativa del triangulo.
// RDVM_TexturaMedalla
//      Textura a aplicar en la medallita que sirve de fondo
//      en el triangulo de madera.
//
// Los siguientes son los modificadores
// aplicables y redefinibles por el usuario (si se indica es default)
// #declare RDVM_VisibleCruz    = on;
//      Valor off no dibuja la cruz.  La cruz original tenia
//      figura de Jesus, que se sustituyo por una mas simple.
//      Este modificador esta previsto para la sencilla
//      sustitucion del crucifijo.
//      Ver RDVM_PuntoCruz.
// #declare RDVM_POV3_1         = off;
//      Valor on activa modo de compatibilidad con POVRay 3.1.
//      En algunas versiones se activara automaticamente.
// #declare RDVM_DefaultTexturaCuentaBasica     = texture ...
//      Define una textura default para las bolitas del rosario.
// #declare RDVM_DefaultTexturaMetalica         = texture ...
//      Define una textura metalica para las cadenas y la decoracion
//      de las bolitas del rosario.
// #declare RDVM_DefaultTexturaMadera           = texture ...
//      Textura default para el triangulo que cierra el rosario.
// #declare RDVM_DefaultMaterialCruz            = material ...
//      Define un material default a aplicar en el crucifijo principal.
// #declare RDVM_DefaultMaterialCruz2           = material ...
//      Define un material default a aplicar en el crucifijo que decora
//      el triangulo de madera.
// #declare RDVM_DefaultTexturaMedalla          = texture ...
//      Define una textura default a aplicar en el circulo de fondo
//      del crucifijo en el triangulo de madera.
//
// Para colocarlo simplemente
// #include "RDVM.inc"
// object { RDVM_Rosario() }
//
// Con la macro de texturas
// #include "RDVM.inc"
// object {
//   RDVM_RosarioDevocionVirgenMaria( 5065, 1.0, 1.0, 30,
//     RDVM_DefaultTexturaCuentaBasica,
//     RDVM_DefaultTexturaMetalica,
//     RDVM_DefaultTexturaMadera,
//     RDVM_DefaultMaterialCruz,
//     RDVM_DefaultMaterialCruz2,
//     RDVM_DefaultTexturaMedalla
//   )
// }
//
// Otro ejemplo con modificador
// #include "RDVM.inc"
// #declare RDVM_DefaultTexturaMetalica         = texture       {
//   average
//   texture_map        {
//     [ 0.5 RDVM_Rust                          ]
//     [ 0.5 RDVM_TexturaMetalica               ]
//   }
// }
// object       { RDVM_Rosario() }
//

#include "colors.inc"
#include "textures.inc"  
#include "metals.inc"   
#include "woods.inc"

#if ( version < 3.2 )
  #ifndef( RDVM_POV3_1 )
    #declare RDVM_POV3_1        = on;
  #end
#else
  #ifndef( RDVM_POV3_1 )
    #declare RDVM_POV3_1        = off;
  #end
#end

#declare RDVM_L                 = 0.001;

#ifndef ( RDVM_VisibleCruz )
  #declare RDVM_VisibleCruz     = on;
#end

#declare RDVM_TexturaCuentaBasica               = texture       {
  pigment               {
    Brown
  }
}

#ifndef ( RDVM_DefaultTexturaCuentaBasica )
  #declare RDVM_DefaultTexturaCuentaBasica      = texture       {
    RDVM_TexturaCuentaBasica
  }
#end

#declare RDVM_TexturaMetalica                   = texture       { 
  pigment               {
    Gold
  }
}

#ifndef ( RDVM_DefaultTexturaMetalica )
  #declare RDVM_DefaultTexturaMetalica          = texture       {
    RDVM_TexturaMetalica
  }
#end

#declare RDVM_TexturaMadera                     = texture       {
  T_Wood26
}

#ifndef ( RDVM_DefaultTexturaMadera )
  #declare RDVM_DefaultTexturaMadera            = texture       {
    RDVM_TexturaMadera
  }
#end


#declare RDVM_MaterialCruz                      = material      {
    #if ( RDVM_POV3_1 )
      texture       {
        pigment               {
          rgbt                <0.4,0.5,0.2,0.5>
        }
      }
    #else
      M_NB_Winebottle_Glass
      texture     {  
        pigment   {
          onion         
          turbulence    0.1
          scale   0.1
          pigment_map     {
            [ 0.0 rgbt <0.0,0.75,0.0,0  >]
            [ 0.5 rgbt <1,1,1,1  >]
          }
          
        }
      }
    #end
  }

#ifndef ( RDVM_DefaultMaterialCruz )
  #declare RDVM_DefaultMaterialCruz             = material       {
    RDVM_MaterialCruz
  }
#end

#declare RDVM_MaterialCruz2                     = material      {
    #if ( RDVM_POV3_1 )
      texture       {
        pigment               {
          rgbt                <0.4,0.5,0.2,0.5>
        }
      }
    #else
      M_NB_Old_Glass     
    #end
  }

#ifndef ( RDVM_DefaultMaterialCruz2 )
  #declare RDVM_DefaultMaterialCruz2            = material       {
    RDVM_MaterialCruz2
  }
#end

#declare RDVM_TexturaMedalla                    = texture       {
  T_Brass_1B  
  normal                {
    wrinkles
    scale               0.01
  }
}

#ifndef ( RDVM_DefaultTexturaMedalla )
  #declare RDVM_DefaultTexturaMedalla           = texture       {
    RDVM_TexturaMedalla
  }
#end

#macro RDVM_Catenaria ( XX, F, Angulo, Y0 )
  #local XX              =
        F*( exp( XX/F )+exp( -XX/F ) )/2+tan( radians( Angulo ) )*XX+Y0-F;
#end

#macro RDVM_CatenariaAngulo ( Pendiente, XX, F, Angulo, BanderaAngulo )
  #local Pendiente      =
        ( exp( XX/F )-exp( -XX/F ) )/2+tan( radians( Angulo ) );
  #if ( BanderaAngulo )
    #local Pendiente    =
                degrees( asin( Pendiente/sqrt( 1+Pendiente*Pendiente ) ) );
  #end
#end

#macro RDVM_RosarioDevocionVirgenMaria
          ( Semilla, Tension1, Tension2, Angulo2,
                TexturaCuentaBasica, TexturaMetal,
                TexturaMadera, MaterialCruz, MaterialCruzMenor, 
                TexturaMedalla )
  #local L                      = RDVM_L;
  #local Aleatorio              = seed( Semilla );
  #local FrenteRosario          = 600*L;
  #local RadioCuentaBasica      = 7*L;
  #local RadioCadenaBasica      = RadioCuentaBasica/4;
  #local LargoCruz    = 136*L;
  #local AnchoCruz    = 82*L;
  #local MaderaCruz   = 15*L;
  #local GruesoCruz   = 7*L;
  #local FraccionCruz = 0.73;
  #local Crucifijo              =
    prism               {
      cubic_spline
      -GruesoCruz/2             ,
      +GruesoCruz/2             ,
      15,
      <-MaderaCruz/2    , 0                             >,
      < MaderaCruz/2    , 0                             >,
      < MaderaCruz/2    , FraccionCruz*LargoCruz-MaderaCruz/2           >,
      < AnchoCruz/2     , FraccionCruz*LargoCruz-MaderaCruz/2           >,
      < AnchoCruz/2     , FraccionCruz*LargoCruz+MaderaCruz/2           >,
      < MaderaCruz/2    , FraccionCruz*LargoCruz+MaderaCruz/2           >,
      < MaderaCruz/2    , LargoCruz                     >,
      <-MaderaCruz/2    , LargoCruz                     >,
      <-MaderaCruz/2    , FraccionCruz*LargoCruz+MaderaCruz/2           >,
      <-AnchoCruz/2     , FraccionCruz*LargoCruz+MaderaCruz/2           >,
      <-AnchoCruz/2     , FraccionCruz*LargoCruz-MaderaCruz/2           >,
      <-MaderaCruz/2    , FraccionCruz*LargoCruz-MaderaCruz/2           >,
      <-MaderaCruz/2    , 0                             >,
      < MaderaCruz/2    , 0                             >,
      < MaderaCruz/2    , FraccionCruz*LargoCruz-MaderaCruz/2           >
      rotate            -90*x
    }  
  #local CuentaBasica           =
    union               {
      sphere            {
        0       , RadioCuentaBasica
        texture         {
          TexturaCuentaBasica
        }
      }
      disc              {
        RadioCuentaBasica*y     , y             ,
        RadioCuentaBasica*tan( radians( 30 ) )
        texture         {
          TexturaMetal
        }
      }
      #local C                  = 0;
      #while ( C < 6 )
        disc              {
          RadioCuentaBasica*y     , y             ,
          RadioCuentaBasica*tan( radians( 30 ) )
          rotate        60*z
          rotate        60*C*y
          texture         {
            TexturaMetal
          }
        }
        #local C                = C+1;
      #end
    }
  #local CadenaBasica           =
    union               {
      difference        {
        torus           {
          RadioCadenaBasica     ,
          RadioCadenaBasica/5
          rotate        90*x
          rotate        10*x
        }
        box             {
          2*RadioCadenaBasica*<0,-1,-1>,
          2*RadioCadenaBasica
        }
        translate       +0.05*RadioCadenaBasica*x
      }
      difference        {
        torus           {
          RadioCadenaBasica     ,
          RadioCadenaBasica/5
          rotate        90*x
          rotate        10*x
        }
        box             {
          2*RadioCadenaBasica*<0,-1,-1>,
          2*RadioCadenaBasica
        }
        translate       +0.05*RadioCadenaBasica*x
        scale   <-1,-1,1>
      }
      texture           {
        TexturaMetal
      }
    }
  union                 {
    #local Y0           = 0;
    #local Longitud     = 0;
    #local Pendiente    = 0;
    #local Angulo       = 0;
    #local XX           = -FrenteRosario/2;
    #local F            = Tension1;
    #local AnguloInterior               = 0;
    #local C            = 0;
    #local YY1          = XX;
    RDVM_Catenaria( YY1, F, Angulo, Y0 )
    #while ( XX < FrenteRosario/2 )
      #local YY         = XX;
      RDVM_Catenaria( YY, F, Angulo, Y0 )
      RDVM_CatenariaAngulo( AnguloInterior, XX, F, Angulo, true )
      RDVM_CatenariaAngulo( Pendiente, XX, F, Angulo, false )
      #local Longitud   = Longitud+
                2*RadioCadenaBasica*cos( radians( AnguloInterior ) )
                *sqrt( 1+Pendiente*Pendiente );
      object            {
        CadenaBasica
        rotate          90*z
        rotate          AnguloInterior*z
        translate       XX*x+YY*y
      }
      #local XX          =
                XX+2*RadioCadenaBasica*cos( radians( AnguloInterior ) );
      #local C          = C+1;
    #end
    #local Y0           = 0;
    #local Angulo       = Angulo2;
    #local XX           = -FrenteRosario/2;
    #local F            = Tension2;
    #local AnguloInterior               = 0;
    #local C            = 0;
    #local YY2          = XX;
    RDVM_Catenaria( YY2, F, -Angulo, Y0 )
    #while ( XX < FrenteRosario/2 )
      #local YY         = XX;
      #if ( XX >= 0 )
        RDVM_Catenaria( YY, F, Angulo, Y0 )
        RDVM_CatenariaAngulo( AnguloInterior, XX, F, Angulo, true )
        RDVM_CatenariaAngulo( Pendiente, XX, F, Angulo, false )
        #local Longitud   = Longitud+
                2*RadioCadenaBasica*cos( radians( AnguloInterior ) )
                *sqrt( 1+Pendiente*Pendiente );
      #else
        RDVM_Catenaria( YY, F, -Angulo, Y0 )
        RDVM_CatenariaAngulo( AnguloInterior, XX, F, -Angulo, true )
        RDVM_CatenariaAngulo( Pendiente, XX, F, -Angulo, false )
        #local Longitud   = Longitud+
                2*RadioCadenaBasica*cos( radians( AnguloInterior ) )
                *sqrt( 1+Pendiente*Pendiente );
      #end
      object            {
        CadenaBasica
        rotate          90*z
        rotate          AnguloInterior*z
        translate       XX*x+( YY+YY1-YY2 )*y
        translate       -RadioCuentaBasica*z
      }
      #local XX          =
                XX+2*RadioCadenaBasica*cos( radians( AnguloInterior ) );
      #local C          = C+1;
    #end
    #local Separacion   = Longitud/66;
    #local XX           = Separacion/2;
    #local Y0           = 0;
    #local Longitud     = 0;
    #local Pendiente    = 0;
    #local Angulo       = 0;
    #local F            = Tension1;
    #local AnguloInterior               = 0;
    #local C            = 1;
    #local Visible              = true;
    #while ( XX < FrenteRosario/2 )
      #local YY         = XX;
      RDVM_Catenaria( YY, F, Angulo, Y0 )
      RDVM_CatenariaAngulo( AnguloInterior, XX, F, Angulo, true )
      #switch ( C )
        #case ( 6 )
        #case ( 8 )
          #local Visible                       = false;
        #break
        #else
          #local Visible                       = true;
        #break
      #end
      #if ( Visible )
        object            {
          CuentaBasica
          rotate          90*z
          rotate          AnguloInterior*z
        rotate
    10*( < rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >-0.5 )
          translate       XX*x+YY*y
        }
        object            {
          CuentaBasica
          rotate          90*z
          rotate          AnguloInterior*z
        rotate
    10*( < rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >-0.5 )
          translate       XX*x+YY*y
          scale           <-1,1,-1>
        }
        #if ( C = 7 )
          object            {
            CuentaBasica
            scale           -1
            rotate          90*z
            rotate          AnguloInterior*z
            translate       XX*x+YY*y
          }
          object            {
            CuentaBasica
            scale           -1
            rotate          90*z
            rotate          AnguloInterior*z
            translate       XX*x+YY*y
            scale           <-1,1,-1>
          }
        #end
      #end
      #local C          = C+1;
      #local XX         =
                XX+Separacion*cos( radians( AnguloInterior ) );
    #end
    #local Y0           = 0;
    #local Longitud     = 0;
    #local Pendiente    = 0;
    #local Angulo       = Angulo2;
    #local F            = Tension2;
    #local AnguloInterior               = 0;
    #local C            = 1;
    #local Visible              = true;
    #local XX           = Separacion/2;
    #while ( XX < FrenteRosario/2 )
      #local YY         = XX;
      RDVM_Catenaria( YY, F, Angulo, Y0 )
      RDVM_CatenariaAngulo( AnguloInterior, XX, F, Angulo, true )
      #switch ( C )
        #case ( 2 )
          #local VerticeTriangulo       =
                        < abs( XX ), YY+YY1-YY2, -RadioCadenaBasica >;
        #case ( 1 )
        #case ( 13 )
        #case ( 15 )
          #local Visible                       = false;
        #break
        #else
          #local Visible                       = true;
        #break
      #end
      #if ( Visible )
        object            {
          CuentaBasica
          rotate          90*z
          rotate          AnguloInterior*z
        rotate
    10*( < rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >-0.5 )
          translate       XX*x+( YY+YY1-YY2 )*y
          translate       -RadioCuentaBasica*z
        }
        object            {
          CuentaBasica
          rotate          90*z
          rotate          AnguloInterior*z
        rotate
    10*( < rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >-0.5 )
          translate       XX*x+( YY+YY1-YY2 )*y
          scale           <-1,1,-1>
          translate       -RadioCuentaBasica*z
        }
        #if ( C = 14 )
          object            {
            CuentaBasica
            scale               -1
            rotate          90*z
            rotate          AnguloInterior*z
            translate       XX*x+( YY+YY1-YY2 )*y
            translate       -RadioCuentaBasica*z
          }
          object            {
            CuentaBasica
            scale               -1
            rotate          90*z
            rotate          AnguloInterior*z
            translate       XX*x+( YY+YY1-YY2 )*y
            scale           <-1,1,-1>
            translate       -RadioCuentaBasica*z
          }
        #end
      #end
      #local C          = C+1;
      #local XX         =
                XX+Separacion*cos( radians( AnguloInterior ) );
    #end
    #local GruesoTriangulo      = RadioCuentaBasica/2;
    prism               {
      RadioCuentaBasica-GruesoTriangulo/2,
      RadioCuentaBasica+GruesoTriangulo/2,
      4,
      < VerticeTriangulo.x      , VerticeTriangulo.y    >,
      <-VerticeTriangulo.x      , VerticeTriangulo.y    >,
      < 0                       ,
        VerticeTriangulo.y-sqrt( 3 )*VerticeTriangulo.x >,
      < VerticeTriangulo.x      , VerticeTriangulo.y    >
      rotate            -90*x
      texture           {
        TexturaMadera
      }
    }
    cylinder            {
      < 0       , VerticeTriangulo.y-sqrt( 3 )/3*VerticeTriangulo.x     ,
        -RadioCuentaBasica                      >,
      < 0       , VerticeTriangulo.y-sqrt( 3 )/3*VerticeTriangulo.x     ,
        -RadioCuentaBasica-GruesoTriangulo*0.6  >,
      sqrt( 3 )/4*VerticeTriangulo.x
      texture           {
        TexturaMedalla
      }
    }
    object              {
      Crucifijo
      translate         -LargoCruz/2*y
      rotate            10*( rand( Aleatorio )-0.5 )*z
      scale             abs( 1/LargoCruz*sqrt( 3 )*VerticeTriangulo.x )
      translate         < 0,
        VerticeTriangulo.y-sqrt( 3 )/2*VerticeTriangulo.x       ,
        -RadioCuentaBasica-GruesoTriangulo*0.6 >
      material           {
        MaterialCruzMenor
      }
    }
    #local YY           = 0;
    #local CordonCruz   = Separacion*7;
    #local Y0           = VerticeTriangulo.y-sqrt( 3 )*VerticeTriangulo.x;
    #while ( YY < CordonCruz )
      object            {
        CadenaBasica
        rotate          90*z
        translate       ( -YY+Y0 )*y-RadioCuentaBasica*z
      }
      #local YY         = YY+2*RadioCadenaBasica;
    #end
    #local YY           = Separacion/2;
    #local C            = 1;
    #local Visible      = true;
    #while ( YY < CordonCruz )
      #switch ( C )
        #case( 1 )
        #case( 3 )
        #case( 7 )
          #local Visible                = false;
        #break
        #else
          #local Visible                = true;
        #break
      #end
      #if ( Visible )
        object            {
          CuentaBasica
        rotate
    10*( < rand( Aleatorio ), rand( Aleatorio ), rand( Aleatorio ) >-0.5 )
          translate       ( -YY+Y0 )*y-RadioCuentaBasica*z
        }
        #if ( C = 2 )
          object            {
            CuentaBasica
            scale               -1
            translate       ( -YY+Y0 )*y-RadioCuentaBasica*z
          }
        #end
      #end
      #local YY         = YY+Separacion;
      #local C          = C+1;
    #end
    #local PuntoCruz    = < 0, Y0-CordonCruz, -RadioCuentaBasica >;
    #if ( RDVM_VisibleCruz )
      object              {
        Crucifijo
        rotate            10*( rand( Aleatorio )-0.5 )*y
        translate         PuntoCruz-LargoCruz*y
        material          {
          MaterialCruz
        }
      }
    #end
    #local DesplazadoFinal      = 0.16*y-RadioCuentaBasica*z;
    translate           DesplazadoFinal
    #declare RDVM_PuntoCruz     = PuntoCruz+DesplazadoFinal;
  }
#end

#macro RDVM_Rosario()
  object        {
    RDVM_RosarioDevocionVirgenMaria( 2012, 0.5, 0.5, 15,
      RDVM_DefaultTexturaCuentaBasica,
      RDVM_DefaultTexturaMetalica,
      RDVM_DefaultTexturaMadera,
      RDVM_DefaultMaterialCruz,
      RDVM_DefaultMaterialCruz2,
      RDVM_DefaultTexturaMedalla
    )
  }
#end

